@@ -1,5 +1,5 @@
 __author__ = "Shyue Ping Ong"
-__date__ = "Apr 3 2013"
-__version__ = "0.4.1"
+__date__ = "Jun 23 2013"
+__version__ = "0.4.2"
 
 from custodian import Custodian
