@@ -34,6 +34,10 @@ from custodian.ansible.actions import FileActions, DictActions
 
 
 class VaspErrorHandler(ErrorHandler, MSONable):
+    """
+    Master VaspErrorHandler class that handles a number of common errors
+    that occur during VASP runs.
+    """
 
     error_msgs = {
         "tet": ["Tetrahedron method fails for NKPT<4",
@@ -54,7 +58,9 @@ class VaspErrorHandler(ErrorHandler, MSONable):
         "triple_product": ["ERROR: the triple product of the basis vectors"],
         "rot_matrix": ["Found some non-integer element in rotation matrix"],
         "brions": ["BRIONS problems: POTIM should be increased"],
-        "pricel": ["internal error in subroutine PRICEL"]
+        "pricel": ["internal error in subroutine PRICEL"],
+        "zpotrf": ["LAPACK: Routine ZPOTRF failed"],
+        "amin": ["One of the lattice vectors is very long (>50 A), but AMIN"]
     }
 
     def __init__(self, output_filename="vasp.out"):
@@ -72,7 +78,7 @@ class VaspErrorHandler(ErrorHandler, MSONable):
         return len(self.errors) > 0
 
     def correct(self):
-        backup()
+        backup(self.output_filename)
         actions = []
         vi = VaspInput.from_directory(".")
 
@@ -82,7 +88,7 @@ class VaspErrorHandler(ErrorHandler, MSONable):
         if "inv_rot_mat" in self.errors:
             actions.append({"dict": "INCAR",
                             "action": {"_set": {"SYMPREC": 1e-8}}})
-        if "brmix" in self.errors:
+        if "brmix" in self.errors or "zpotrf" in self.errors:
             actions.append({"dict": "INCAR",
                             "action": {"_set": {"ISYM": 0}}})
         if "subspacematrix" in self.errors or "rspher" in self.errors or \
@@ -92,6 +98,9 @@ class VaspErrorHandler(ErrorHandler, MSONable):
         if "tetirr" in self.errors or "incorrect_shift" in self.errors:
             actions.append({"dict": "KPOINTS",
                             "action": {"_set": {"generation_style": "Gamma"}}})
+        if "amin" in self.errors:
+            actions.append({"dict": "INCAR",
+                            "action": {"_set": {"AMIN": "0.01"}}})
         if "too_few_bands" in self.errors:
             if "NBANDS" in vi["INCAR"]:
                 nbands = int(vi["INCAR"]["NBANDS"])
@@ -123,9 +132,11 @@ class VaspErrorHandler(ErrorHandler, MSONable):
             actions.append({"dict": "POSCAR",
                             "action": {"_set": {"structure": new_s.to_dict}},
                             "transformation": trans.to_dict})
+            actions.append({"dict": "INCAR",
+                            "action": {"_set": {"SYMPREC": 1e-8}}})
 
         if "brions" in self.errors:
-            potim = vi["INCAR"].get("POTIM", 0.5) + 0.1
+            potim = float(vi["INCAR"].get("POTIM", 0.5)) + 0.1
             actions.append({"dict": "INCAR",
                             "action": {"_set": {"POTIM": potim}}})
         m = Modder()
@@ -184,7 +195,7 @@ class MeshSymmetryErrorHandler(ErrorHandler, MSONable):
         return False
 
     def correct(self):
-        backup()
+        backup(self.output_filename)
         vi = VaspInput.from_directory(".")
         m = reduce(operator.mul, vi["KPOINTS"].kpts[0])
         m = max(int(round(m ** (1 / 3))), 1)
@@ -231,10 +242,10 @@ class UnconvergedErrorHandler(ErrorHandler, MSONable):
     def check(self):
         try:
             v = Vasprun(self.output_filename)
-            if not v.converged:
-                return True
         except:
-            pass
+            return False
+        if not v.converged:
+            return True
         return False
 
     def correct(self):
@@ -277,6 +288,65 @@ class UnconvergedErrorHandler(ErrorHandler, MSONable):
         return cls(d["output_filename"])
 
 
+class PotimErrorHandler(ErrorHandler, MSONable):
+    """
+    Check if a run has excessively large positive energy changes. 
+    This is typically caused by too large a POTIM. Runs typically 
+    end up crashing with some other error (e.g. BRMIX) as the geometry
+    gets progressively worse.
+    """
+    def __init__(self, input_filename="POSCAR", 
+                 output_filename="OSZICAR", dE_threshold=1):
+        self.input_filename = input_filename
+        self.output_filename = output_filename
+        self.dE_threshold = dE_threshold
+        
+    def check(self):
+        try:
+            oszicar = Oszicar(self.output_filename)
+            n = len(Poscar.from_file(self.input_filename).structure)
+            max_dE = max([s['dE'] for s in oszicar.ionic_steps[1:]]) / n
+            if max_dE > self.dE_threshold:
+                return True
+        except:
+            return False
+    
+    def correct(self):
+        backup()
+        vi = VaspInput.from_directory(".")
+        potim = float(vi["INCAR"].get("POTIM", 0.5)) * 0.5
+        actions = [{"dict": "INCAR",
+                    "action": {"_set": {"POTIM": potim}}}]
+        m = Modder()
+        modified = []
+        for a in actions:
+            modified.append(a["dict"])
+            vi[a["dict"]] = m.modify_object(a["action"], vi[a["dict"]])
+        for f in modified:
+            vi[f].write_file(f)
+        return {"errors": ["POTIM"], "actions": actions}
+    
+    def __str__(self):
+        return "Large positive energy change (POTIM)"
+
+    @property
+    def is_monitor(self):
+        return True
+
+    @property
+    def to_dict(self):
+        return {"@module": self.__class__.__module__,
+                "@class": self.__class__.__name__,
+                "input_filename": self.input_filename,
+                "output_filename": self.output_filename,
+                "dE_threshold": self.dE_threshold}
+
+    @classmethod
+    def from_dict(cls, d):
+        return cls(d["input_filename"], d["output_filename"],
+                   d["dE_threshold"])
+    
+    
 class FrozenJobErrorHandler(ErrorHandler):
 
     def __init__(self, output_filename="vasp.out", timeout=3600):
@@ -293,7 +363,7 @@ class FrozenJobErrorHandler(ErrorHandler):
             return True
 
     def correct(self):
-        backup()
+        backup(self.output_filename)
         p = Poscar.from_file("POSCAR")
         s = p.structure
         trans = PerturbStructureTransformation(0.05)
@@ -336,10 +406,13 @@ class NonConvergingErrorHandler(ErrorHandler, MSONable):
     def check(self):
         vi = VaspInput.from_directory(".")
         nelm = vi["INCAR"].get("NELM", 60)
-        oszicar = Oszicar(self.output_filename)
-        esteps = oszicar.ionic_steps
-        if len(esteps) > 10:
-            return all([len(e) == nelm for e in esteps[-11:-1]])
+        try:
+            oszicar = Oszicar(self.output_filename)
+            esteps = oszicar.ionic_steps
+            if len(esteps) > 10:
+                return all([len(e) == nelm for e in esteps[-11:-1]])
+        except:
+            pass
         return False
 
     def correct(self):
@@ -364,13 +437,14 @@ class NonConvergingErrorHandler(ErrorHandler, MSONable):
         return cls(d["output_filename"])
 
 
-def backup():
+def backup(outfile="vasp.out"):
     error_num = max([0] + [int(f.split(".")[1])
                            for f in glob.glob("error.*.tar.gz")])
     filename = "error.{}.tar.gz".format(error_num + 1)
     logging.info("Backing up run to {}.".format(filename))
     tar = tarfile.open(filename, "w:gz")
-    for f in os.listdir("."):
-        if not (f.startswith("error") and f.endswith(".tar.gz")):
+    vaspfiles = ["INCAR", "KPOINTS", "POSCAR", "OUTCAR", outfile, "vasprun.xml"]
+    for f in vaspfiles:
+        if os.path.exists(f):
             tar.add(f)
     tar.close()
